@@ -19,13 +19,6 @@
 
 #include "interfaces_debug.h"
 
-static QString createId()
-{
-    return QCoreApplication::instance()->applicationName() + QString::number(QCoreApplication::applicationPid());
-}
-
-Q_GLOBAL_STATIC_WITH_ARGS(QString, s_keyId, (createId()));
-
 DevicesModel::DevicesModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_dbusInterface(new DaemonDbusInterface(this))
@@ -34,7 +27,7 @@ DevicesModel::DevicesModel(QObject *parent)
     connect(this, &QAbstractItemModel::rowsRemoved, this, &DevicesModel::rowsChanged);
     connect(this, &QAbstractItemModel::rowsInserted, this, &DevicesModel::rowsChanged);
 
-    connect(m_dbusInterface, SIGNAL(deviceAdded(QString)), this, SLOT(deviceAdded(QString)));
+    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceAdded, this, &DevicesModel::deviceAdded);
     connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged, this, &DevicesModel::deviceUpdated);
     connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceRemoved, this, &DevicesModel::deviceRemoved);
 
@@ -101,9 +94,8 @@ void DevicesModel::deviceRemoved(const QString &id)
     }
 }
 
-void DevicesModel::deviceUpdated(const QString &id, bool isVisible)
+void DevicesModel::deviceUpdated(const QString &id)
 {
-    Q_UNUSED(isVisible);
     int row = rowForDevice(id);
 
     if (row < 0) {
@@ -139,6 +131,8 @@ void DevicesModel::setDisplayFilter(int flags)
     m_displayFilter = (StatusFilterFlag)flags;
 
     refreshDeviceList();
+
+    Q_EMIT displayFilterChanged(flags);
 }
 
 void DevicesModel::refreshDeviceList()
@@ -184,17 +178,10 @@ void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher *watcher)
 void DevicesModel::appendDevice(DeviceDbusInterface *dev)
 {
     m_deviceList.append(dev);
-    connect(dev, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, &DevicesModel::nameChanged);
-}
-
-void DevicesModel::nameChanged(const QString &newName)
-{
-    Q_UNUSED(newName);
-    DeviceDbusInterface *device = static_cast<DeviceDbusInterface *>(sender());
-
-    Q_ASSERT(rowForDevice(device->id()) >= 0);
-
-    deviceUpdated(device->id(), true);
+    connect(dev, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, [this, dev]() {
+        Q_ASSERT(rowForDevice(dev->id()) >= 0);
+        deviceUpdated(dev->id());
+    });
 }
 
 void DevicesModel::clearDevices()
@@ -255,6 +242,16 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
     }
 }
 
+DeviceDbusInterface *DevicesModel::deviceForId(const QString &id) const
+{
+    for (auto dev : m_deviceList) {
+        if (dev->id() == id) {
+            return dev;
+        }
+    }
+    return nullptr;
+}
+
 DeviceDbusInterface *DevicesModel::getDevice(int row) const
 {
     if (row < 0 || row >= m_deviceList.size()) {
@@ -281,3 +278,5 @@ bool DevicesModel::passesFilter(DeviceDbusInterface *dev) const
 
     return !((onlyReachable && !dev->isReachable()) || (onlyPaired && !dev->isPaired()));
 }
+
+#include "moc_devicesmodel.cpp"
